@@ -398,6 +398,8 @@ module SiSU_XML_munge
       if dob.of=='group'
         dob.obj.gsub!(/#{Mx[:gl_bullet]}/,'● ')
       end
+      dob.obj.gsub!(/#{Mx[:url_o]}([a-zA-Z0-9._-]+\@\S+?\.[a-zA-Z0-9._-]+)#{Mx[:url_c]}/,
+        %{#{@brace_url.xml_open}\\1#{@brace_url.xml_close}})
       dob.obj.gsub!(/#{Dx[:url_o]}/,"#{Dx[:url_o_xml]}")
       dob.obj.gsub!(/#{Dx[:url_c]}/,"#{Dx[:url_c_xml]}")
       dob.obj.gsub!(/&nbsp;|#{Mx[:nbsp]}/m,'&#160;')
