@@ -64,14 +64,14 @@ module  SiSU_CGI
   class SiSU_search
     def initialize(opt)
       @opt=opt
-      @webserv=@opt.files[0].to_s.strip #verify @opt.files[0].class
+      @webserv=@opt.files[0].to_s.strip
     end
     def search_info
      a=%{
           For help on sisu search, type:
             sisu --help search
-    }
-        SiSU_Screen::Ansi.new(@opt.cmd,a).print_grey
+      }
+      SiSU_Screen::Ansi.new(@opt.cmd,a).print_grey
     end
     def read
       SiSU_CGI_sqlite::SiSU_search_sqlite.new(@opt,@webserv).sqlite
