@@ -77,7 +77,9 @@ module SiSU_Concordance
         @env,@md=@particulars.env,@particulars.md
         loc=@env.url.output_tell
         unless @md.opt.cmd =~/q/
-          tool=(@md.opt.cmd =~/[MVv]/) ? "#{@env.program.web_browser} #{@md.file.output_path.html_concordance.dir}/#{@md.file.base_filename.html_concordance}" : @md.fns
+          tool=(@md.opt.cmd =~/[MVv]/) \
+          ? "#{@env.program.web_browser} #{@md.file.output_path.html_concordance.dir}/#{@md.file.base_filename.html_concordance}" \
+          : "[#{@opt.f_pth[:lng_is]}]"
           @md.opt.cmd=~/[MVvz]/ \
           ? SiSU_Screen::Ansi.new(@md.opt.cmd,"Concordance",tool).grey_title_hi \
           : SiSU_Screen::Ansi.new(@md.opt.cmd,'Concordance',tool).green_title_hi
