@@ -342,7 +342,8 @@ WOK
     margin-right: 2em;
     margin-top: 10px;
     margin-bottom: 0px;
-    text-indent: 0mm;
+    padding-left: 0em;
+    text-indent: 0em;
   }
   p, h0, h1, h2, h3, h4, h5, h6 {
     display: block;
@@ -357,16 +358,431 @@ WOK
     margin-top: 3px;
     margin-bottom: 3px;
   }
+
+  /* indent */
+
   p.norm { }
-  p.i1 {margin-left: 1em;}
-  p.i2 {margin-left: 2em;}
-  p.i3 {margin-left: 3em;}
-  p.i4 {margin-left: 4em;}
-  p.i5 {margin-left: 5em;}
-  p.i6 {margin-left: 6em;}
-  p.i7 {margin-left: 7em;}
-  p.i8 {margin-left: 8em;}
-  p.i9 {margin-left: 9em;}
+  p.i1 {padding-left: 1em;}
+  p.i2 {padding-left: 2em;}
+  p.i3 {padding-left: 3em;}
+  p.i4 {padding-left: 4em;}
+  p.i5 {padding-left: 5em;}
+  p.i6 {padding-left: 6em;}
+  p.i7 {padding-left: 7em;}
+  p.i8 {padding-left: 8em;}
+  p.i9 {padding-left: 9em;}
+
+  /* hanging indent */
+
+  p.h0i0 {
+    padding-left: 0em;
+    text-indent:  0em;
+  }
+  p.h0i1 {
+    padding-left: 1em;
+    text-indent: -1em;
+  }
+  p.h0i2 {
+    padding-left: 2em;
+    text-indent: -2em;
+  }
+  p.h0i3 {
+    padding-left: 3em;
+    text-indent: -3em;
+  }
+  p.h0i4 {
+    padding-left: 4em;
+    text-indent: -4em;
+  }
+  p.h0i5 {
+    padding-left: 5em;
+    text-indent: -5em;
+  }
+  p.h0i6 {
+    padding-left: 6em;
+    text-indent: -6em;
+  }
+  p.h0i7 {
+    padding-left: 7em;
+    text-indent: -7em;
+  }
+  p.h0i8 {
+    padding-left: 8em;
+    text-indent: -8em;
+  }
+  p.h0i9 {
+    padding-left: 9em;
+    text-indent: -9em;
+  }
+
+  p.h1i0 {
+    padding-left: 0em;
+    text-indent:  1em;
+  }
+  p.h1i1 {
+    padding-left: 1em;
+    text-indent:  0em;
+  }
+  p.h1i2 {
+    padding-left: 2em;
+    text-indent: -1em;
+  }
+  p.h1i3 {
+    padding-left: 3em;
+    text-indent: -2em;
+  }
+  p.h1i4 {
+    padding-left: 4em;
+    text-indent: -3em;
+  }
+  p.h1i5 {
+    padding-left: 5em;
+    text-indent: -4em;
+  }
+  p.h1i6 {
+    padding-left: 6em;
+    text-indent: -5em;
+  }
+  p.h1i7 {
+    padding-left: 7em;
+    text-indent: -6em;
+  }
+  p.h1i8 {
+    padding-left: 8em;
+    text-indent: -7em;
+  }
+  p.h1i9 {
+    padding-left: 9em;
+    text-indent: -8em;
+  }
+
+  p.h2i0 {
+    padding-left: 0em;
+    text-indent:  2em;
+  }
+  p.h2i1 {
+    padding-left: 1em;
+    text-indent:  1em;
+  }
+  p.h2i2 {
+    padding-left: 2em;
+    text-indent:  0em;
+  }
+  p.h2i3 {
+    padding-left: 3em;
+    text-indent: -1em;
+  }
+  p.h2i4 {
+    padding-left: 4em;
+    text-indent: -2em;
+  }
+  p.h2i5 {
+    padding-left: 5em;
+    text-indent: -3em;
+  }
+  p.h2i6 {
+    padding-left: 6em;
+    text-indent: -4em;
+  }
+  p.h2i7 {
+    padding-left: 7em;
+    text-indent: -5em;
+  }
+  p.h2i8 {
+    padding-left: 8em;
+    text-indent: -6em;
+  }
+  p.h2i9 {
+    padding-left: 9em;
+    text-indent: -7em;
+  }
+
+  p.h3i0 {
+    padding-left: 0em;
+    text-indent:  3em;
+  }
+  p.h3i1 {
+    padding-left: 1em;
+    text-indent:  2em;
+  }
+  p.h3i2 {
+    padding-left: 2em;
+    text-indent:  1em;
+  }
+  p.h3i3 {
+    padding-left: 3em;
+    text-indent:  0em;
+  }
+  p.h3i4 {
+    padding-left: 4em;
+    text-indent: -1em;
+  }
+  p.h3i5 {
+    padding-left: 5em;
+    text-indent: -2em;
+  }
+  p.h3i6 {
+    padding-left: 6em;
+    text-indent: -3em;
+  }
+  p.h3i7 {
+    padding-left: 7em;
+    text-indent: -4em;
+  }
+  p.h3i8 {
+    padding-left: 8em;
+    text-indent: -5em;
+  }
+  p.h3i9 {
+    padding-left: 9em;
+    text-indent: -6em;
+  }
+
+  p.h4i0 {
+    padding-left: 0em;
+    text-indent:  4em;
+  }
+  p.h4i1 {
+    padding-left: 1em;
+    text-indent:  3em;
+  }
+  p.h4i2 {
+    padding-left: 2em;
+    text-indent:  2em;
+  }
+  p.h4i3 {
+    padding-left: 3em;
+    text-indent:  1em;
+  }
+  p.h4i4 {
+    padding-left: 4em;
+    text-indent:  0em;
+  }
+  p.h4i5 {
+    padding-left: 5em;
+    text-indent: -1em;
+  }
+  p.h4i6 {
+    padding-left: 6em;
+    text-indent: -2em;
+  }
+  p.h4i7 {
+    padding-left: 7em;
+    text-indent: -3em;
+  }
+  p.h4i8 {
+    padding-left: 8em;
+    text-indent: -4em;
+  }
+  p.h4i9 {
+    padding-left: 9em;
+    text-indent: -5em;
+  }
+
+  p.h5i0 {
+    padding-left: 0em;
+    text-indent:  5em;
+  }
+  p.h5i1 {
+    padding-left: 1em;
+    text-indent:  4em;
+  }
+  p.h5i2 {
+    padding-left: 2em;
+    text-indent:  3em;
+  }
+  p.h5i3 {
+    padding-left: 3em;
+    text-indent:  2em;
+  }
+  p.h5i4 {
+    padding-left: 4em;
+    text-indent:  1em;
+  }
+  p.h5i5 {
+    padding-left: 5em;
+    text-indent:  0em;
+  }
+  p.h5i6 {
+    padding-left: 6em;
+    text-indent: -1em;
+  }
+  p.h5i7 {
+    padding-left: 7em;
+    text-indent: -2em;
+  }
+  p.h5i8 {
+    padding-left: 8em;
+    text-indent: -3em;
+  }
+  p.h5i9 {
+    padding-left: 9em;
+    text-indent: -4em;
+  }
+
+  p.h6i0 {
+    padding-left: 0em;
+    text-indent:  6em;
+  }
+  p.h6i1 {
+    padding-left: 1em;
+    text-indent:  5em;
+  }
+  p.h6i2 {
+    padding-left: 2em;
+    text-indent:  4em;
+  }
+  p.h6i3 {
+    padding-left: 3em;
+    text-indent:  3em;
+  }
+  p.h6i4 {
+    padding-left: 4em;
+    text-indent:  2em;
+  }
+  p.h6i5 {
+    padding-left: 5em;
+    text-indent:  1em;
+  }
+  p.h6i6 {
+    padding-left: 6em;
+    text-indent:  0em;
+  }
+  p.h6i7 {
+    padding-left: 7em;
+    text-indent: -1em;
+  }
+  p.h6i8 {
+    padding-left: 8em;
+    text-indent: -2em;
+  }
+  p.h6i9 {
+    padding-left: 9em;
+    text-indent: -3em;
+  }
+
+  p.h7i0 {
+    padding-left: 0em;
+    text-indent:  7em;
+  }
+  p.h7i1 {
+    padding-left: 1em;
+    text-indent:  6em;
+  }
+  p.h7i2 {
+    padding-left: 2em;
+    text-indent:  5em;
+  }
+  p.h7i3 {
+    padding-left: 3em;
+    text-indent:  4em;
+  }
+  p.h7i4 {
+    padding-left: 4em;
+    text-indent:  3em;
+  }
+  p.h7i5 {
+    padding-left: 5em;
+    text-indent:  2em;
+  }
+  p.h7i6 {
+    padding-left: 6em;
+    text-indent:  1em;
+  }
+  p.h7i7 {
+    padding-left: 7em;
+    text-indent:  0em;
+  }
+  p.h7i8 {
+    padding-left: 8em;
+    text-indent: -1em;
+  }
+  p.h7i9 {
+    padding-left: 9em;
+    text-indent: -2em;
+  }
+
+  p.h8i0 {
+    padding-left: 0em;
+    text-indent:  8em;
+  }
+  p.h8i1 {
+    padding-left: 1em;
+    text-indent:  7em;
+  }
+  p.h8i2 {
+    padding-left: 2em;
+    text-indent:  6em;
+  }
+  p.h8i3 {
+    padding-left: 3em;
+    text-indent:  5em;
+  }
+  p.h8i4 {
+    padding-left: 4em;
+    text-indent:  4em;
+  }
+  p.h8i5 {
+    padding-left: 5em;
+    text-indent:  3em;
+  }
+  p.h8i6 {
+    padding-left: 6em;
+    text-indent:  2em;
+  }
+  p.h8i7 {
+    padding-left: 7em;
+    text-indent:  1em;
+  }
+  p.h8i8 {
+    padding-left: 8em;
+    text-indent:  0em;
+  }
+  p.h8i9 {
+    padding-left: 9em;
+    text-indent: -1em;
+  }
+
+  p.h9i0 {
+    padding-left: 0em;
+    text-indent:  9em;
+  }
+  p.h9i1 {
+    padding-left: 1em;
+    text-indent:  8em;
+  }
+  p.h9i2 {
+    padding-left: 2em;
+    text-indent:  7em;
+  }
+  p.h9i3 {
+    padding-left: 3em;
+    text-indent:  6em;
+  }
+  p.h9i4 {
+    padding-left: 4em;
+    text-indent:  5em;
+  }
+  p.h9i5 {
+    padding-left: 5em;
+    text-indent:  4em;
+  }
+  p.h9i6 {
+    padding-left: 6em;
+    text-indent:  3em;
+  }
+  p.h9i7 {
+    padding-left: 7em;
+    text-indent:  2em;
+  }
+  p.h9i8 {
+    padding-left: 8em;
+    text-indent:  1em;
+  }
+  p.h9i9 {
+    padding-left: 9em;
+    text-indent:  0em;
+  }
 
   p.it0 {
     margin-left: 0em;
@@ -1339,35 +1755,446 @@ WOK
       text-align: left;
     }
     text[class|="indent0"] {
-      margin-left: 10%;
+      padding-left: 10%;
     }
     text[class|="indent1"] {
-      margin-left: 15%;
+      padding-left: 15%;
     }
     text[class|="indent2"] {
-      margin-left: 20%;
+      padding-left: 20%;
     }
     text[class|="indent3"] {
-      margin-left: 25%;
+      padding-left: 25%;
     }
     text[class|="indent4"] {
-      margin-left: 30%;
+      padding-left: 30%;
     }
     text[class|="indent5"] {
-      margin-left: 35%;
+      padding-left: 35%;
     }
     text[class|="indent6"] {
-      margin-left: 40%;
+      padding-left: 40%;
     }
     text[class|="indent7"] {
-      margin-left: 45%;
+      padding-left: 45%;
     }
     text[class|="indent8"] {
-      margin-left: 50%;
+      padding-left: 50%;
     }
     text[class|="indent9"] {
-      margin-left: 55%;
+      padding-left: 55%;
     }
+
+    text[class|="hang0_indent0"] {
+      padding-left: 10%;
+      text-indent:   0%;
+    }
+    text[class|="hang0_indent1"] {
+      padding-left: 15%;
+      text-indent:  -5%;
+    }
+    text[class|="hang0_indent2"] {
+      padding-left: 20%;
+      text-indent: -10%;
+    }
+    text[class|="hang0_indent3"] {
+      padding-left: 25%;
+      text-indent: -15%;
+    }
+    text[class|="hang0_indent4"] {
+      padding-left: 30%;
+      text-indent: -20%;
+    }
+    text[class|="hang0_indent5"] {
+      padding-left: 35%;
+      text-indent: -25%;
+    }
+    text[class|="hang0_indent6"] {
+      padding-left: 40%;
+      text-indent: -30%;
+    }
+    text[class|="hang0_indent7"] {
+      padding-left: 45%;
+      text-indent: -35%;
+    }
+    text[class|="hang0_indent8"] {
+      padding-left: 50%;
+      text-indent: -40%;
+    }
+    text[class|="hang0_indent9"] {
+      padding-left: 55%;
+      text-indent: -45%;
+    }
+
+    text[class|="hang1_indent0"] {
+      padding-left: 10%;
+      text-indent:   5%;
+    }
+    text[class|="hang1_indent1"] {
+      padding-left: 15%;
+      text-indent:   0%;
+    }
+    text[class|="hang1_indent2"] {
+      padding-left: 20%;
+      text-indent:  -5%;
+    }
+    text[class|="hang1_indent3"] {
+      padding-left: 25%;
+      text-indent: -10%;
+    }
+    text[class|="hang1_indent4"] {
+      padding-left: 30%;
+      text-indent: -15%;
+    }
+    text[class|="hang1_indent5"] {
+      padding-left: 35%;
+      text-indent: -20%;
+    }
+    text[class|="hang1_indent6"] {
+      padding-left: 40%;
+      text-indent: -25%;
+    }
+    text[class|="hang1_indent7"] {
+      padding-left: 45%;
+      text-indent: -30%;
+    }
+    text[class|="hang1_indent8"] {
+      padding-left: 50%;
+      text-indent: -35%;
+    }
+    text[class|="hang1_indent9"] {
+      padding-left: 55%;
+      text-indent: -40%;
+    }
+
+    text[class|="hang2_indent0"] {
+      padding-left: 10%;
+      text-indent:  10%;
+    }
+    text[class|="hang2_indent1"] {
+      padding-left: 15%;
+      text-indent:   5%;
+    }
+    text[class|="hang2_indent2"] {
+      padding-left: 20%;
+      text-indent:   0%;
+    }
+    text[class|="hang2_indent3"] {
+      padding-left: 25%;
+      text-indent:  -5%;
+    }
+    text[class|="hang2_indent4"] {
+      padding-left: 30%;
+      text-indent: -10%;
+    }
+    text[class|="hang2_indent5"] {
+      padding-left: 35%;
+      text-indent: -15%;
+    }
+    text[class|="hang2_indent6"] {
+      padding-left: 40%;
+      text-indent: -20%;
+    }
+    text[class|="hang2_indent7"] {
+      padding-left: 45%;
+      text-indent: -25%;
+    }
+    text[class|="hang2_indent8"] {
+      padding-left: 50%;
+      text-indent: -30%;
+    }
+    text[class|="hang2_indent9"] {
+      padding-left: 55%;
+      text-indent: -35%;
+    }
+
+    text[class|="hang3_indent0"] {
+      padding-left: 10%;
+      text-indent:  15%;
+    }
+    text[class|="hang3_indent1"] {
+      padding-left: 15%;
+      text-indent:  10%;
+    }
+    text[class|="hang3_indent2"] {
+      padding-left: 20%;
+      text-indent:   5%;
+    }
+    text[class|="hang3_indent3"] {
+      padding-left: 25%;
+      text-indent:   0%;
+    }
+    text[class|="hang3_indent4"] {
+      padding-left: 30%;
+      text-indent:  -5%;
+    }
+    text[class|="hang3_indent5"] {
+      padding-left: 35%;
+      text-indent: -10%;
+    }
+    text[class|="hang3_indent6"] {
+      padding-left: 40%;
+      text-indent: -15%;
+    }
+    text[class|="hang3_indent7"] {
+      padding-left: 45%;
+      text-indent: -20%;
+    }
+    text[class|="hang3_indent8"] {
+      padding-left: 50%;
+      text-indent: -25%;
+    }
+    text[class|="hang3_indent9"] {
+      padding-left: 55%;
+      text-indent: -30%;
+    }
+
+    text[class|="hang4_indent0"] {
+      padding-left: 10%;
+      text-indent:  20%;
+    }
+    text[class|="hang4_indent1"] {
+      padding-left: 15%;
+      text-indent:  15%;
+    }
+    text[class|="hang4_indent2"] {
+      padding-left: 20%;
+      text-indent:  10%;
+    }
+    text[class|="hang4_indent3"] {
+      padding-left: 25%;
+      text-indent:   5%;
+    }
+    text[class|="hang4_indent4"] {
+      padding-left: 30%;
+      text-indent:   0%;
+    }
+    text[class|="hang4_indent5"] {
+      padding-left: 35%;
+      text-indent:  -5%;
+    }
+    text[class|="hang4_indent6"] {
+      padding-left: 40%;
+      text-indent: -10%;
+    }
+    text[class|="hang4_indent7"] {
+      padding-left: 45%;
+      text-indent: -15%;
+    }
+    text[class|="hang4_indent8"] {
+      padding-left: 50%;
+      text-indent: -20%;
+    }
+    text[class|="hang4_indent9"] {
+      padding-left: 55%;
+      text-indent: -25%;
+    }
+
+    text[class|="hang5_indent0"] {
+      padding-left: 10%;
+      text-indent:  25%;
+    }
+    text[class|="hang5_indent1"] {
+      padding-left: 15%;
+      text-indent:  20%;
+    }
+    text[class|="hang5_indent2"] {
+      padding-left: 20%;
+      text-indent:  15%;
+    }
+    text[class|="hang5_indent3"] {
+      padding-left: 25%;
+      text-indent:  10%;
+    }
+    text[class|="hang5_indent4"] {
+      padding-left: 30%;
+      text-indent:   5%;
+    }
+    text[class|="hang5_indent5"] {
+      padding-left: 35%;
+      text-indent:   0%;
+    }
+    text[class|="hang5_indent6"] {
+      padding-left: 40%;
+      text-indent:  -5%;
+    }
+    text[class|="hang5_indent7"] {
+      padding-left: 45%;
+      text-indent: -10%;
+    }
+    text[class|="hang5_indent8"] {
+      padding-left: 50%;
+      text-indent: -15%;
+    }
+    text[class|="hang5_indent9"] {
+      padding-left: 55%;
+      text-indent: -20%;
+    }
+
+    text[class|="hang6_indent0"] {
+      padding-left: 10%;
+      text-indent:  30%;
+    }
+    text[class|="hang6_indent1"] {
+      padding-left: 15%;
+      text-indent:  25%;
+    }
+    text[class|="hang6_indent2"] {
+      padding-left: 20%;
+      text-indent:  20%;
+    }
+    text[class|="hang6_indent3"] {
+      padding-left: 25%;
+      text-indent:  15%;
+    }
+    text[class|="hang6_indent4"] {
+      padding-left: 30%;
+      text-indent:  10%;
+    }
+    text[class|="hang6_indent5"] {
+      padding-left: 35%;
+      text-indent:   5%;
+    }
+    text[class|="hang6_indent6"] {
+      padding-left: 40%;
+      text-indent:   0%;
+    }
+    text[class|="hang6_indent7"] {
+      padding-left: 45%;
+      text-indent:  -5%;
+    }
+    text[class|="hang6_indent8"] {
+      padding-left: 50%;
+      text-indent: -10%;
+    }
+    text[class|="hang6_indent9"] {
+      padding-left: 55%;
+      text-indent: -15%;
+    }
+
+    text[class|="hang7_indent0"] {
+      padding-left: 10%;
+      text-indent:  35%;
+    }
+    text[class|="hang7_indent1"] {
+      padding-left: 15%;
+      text-indent:  30%;
+    }
+    text[class|="hang7_indent2"] {
+      padding-left: 20%;
+      text-indent:  25%;
+    }
+    text[class|="hang7_indent3"] {
+      padding-left: 25%;
+      text-indent:  20%;
+    }
+    text[class|="hang7_indent4"] {
+      padding-left: 30%;
+      text-indent:  15%;
+    }
+    text[class|="hang7_indent5"] {
+      padding-left: 35%;
+      text-indent:  10%;
+    }
+    text[class|="hang7_indent6"] {
+      padding-left: 40%;
+      text-indent:   5%;
+    }
+    text[class|="hang7_indent7"] {
+      padding-left: 45%;
+      text-indent:   0%;
+    }
+    text[class|="hang7_indent8"] {
+      padding-left: 50%;
+      text-indent:  -5%;
+    }
+    text[class|="hang7_indent9"] {
+      padding-left: 55%;
+      text-indent: -10%;
+    }
+
+    text[class|="hang8_indent0"] {
+      padding-left: 10%;
+      text-indent:  40%;
+    }
+    text[class|="hang8_indent1"] {
+      padding-left: 15%;
+      text-indent:  35%;
+    }
+    text[class|="hang8_indent2"] {
+      padding-left: 20%;
+      text-indent:  30%;
+    }
+    text[class|="hang8_indent3"] {
+      padding-left: 25%;
+      text-indent:  25%;
+    }
+    text[class|="hang8_indent4"] {
+      padding-left: 30%;
+      text-indent:  20%;
+    }
+    text[class|="hang8_indent5"] {
+      padding-left: 35%;
+      text-indent:  15%;
+    }
+    text[class|="hang8_indent6"] {
+      padding-left: 40%;
+      text-indent:  10%;
+    }
+    text[class|="hang8_indent7"] {
+      padding-left: 45%;
+      text-indent:   5%;
+    }
+    text[class|="hang8_indent8"] {
+      padding-left: 50%;
+      text-indent:   0%;
+    }
+    text[class|="hang8_indent9"] {
+      padding-left: 55%;
+      text-indent:  -5%;
+    }
+
+    text[class|="hang9_indent0"] {
+      padding-left: 10%;
+      text-indent:  45%;
+    }
+    text[class|="hang9_indent1"] {
+      padding-left: 15%;
+      text-indent:  40%;
+    }
+    text[class|="hang9_indent2"] {
+      padding-left: 20%;
+      text-indent:  35%;
+    }
+    text[class|="hang9_indent3"] {
+      padding-left: 25%;
+      text-indent:  30%;
+    }
+    text[class|="hang9_indent4"] {
+      padding-left: 30%;
+      text-indent:  25%;
+    }
+    text[class|="hang9_indent5"] {
+      padding-left: 35%;
+      text-indent:  20%;
+    }
+    text[class|="hang9_indent6"] {
+      padding-left: 40%;
+      text-indent:  15%;
+    }
+    text[class|="hang9_indent7"] {
+      padding-left: 45%;
+      text-indent:  10%;
+    }
+    text[class|="hang9_indent8"] {
+      padding-left: 50%;
+      text-indent:   5%;
+    }
+    text[class|="hang9_indent9"] {
+      padding-left: 55%;
+      text-indent:   0%;
+    }
+
     text[class|="indent_bullet"] {
       text-indent: 0%;
     }
@@ -1645,59 +2472,479 @@ WOK
       font-weight: bold;
       text-align: left;
     }
+    text[class|="indent0"] {
+      padding-left: 10%;
+    }
     text[class|="indent1"] {
-      margin-left: 10%;
+      padding-left: 15%;
     }
     text[class|="indent2"] {
-      margin-left: 15%;
+      padding-left: 20%;
     }
     text[class|="indent3"] {
-      margin-left: 20%;
+      padding-left: 25%;
     }
     text[class|="indent4"] {
-      margin-left: 25%;
+      padding-left: 30%;
     }
     text[class|="indent5"] {
-      margin-left: 30%;
+      padding-left: 35%;
     }
     text[class|="indent6"] {
-      margin-left: 35%;
+      padding-left: 40%;
     }
     text[class|="indent7"] {
-      margin-left: 40%;
+      padding-left: 45%;
     }
     text[class|="indent8"] {
-      margin-left: 45%;
+      padding-left: 50%;
     }
     text[class|="indent9"] {
-      margin-left: 50%;
+      padding-left: 55%;
+    }
+
+    text[class|="hang0_indent0"] {
+      padding-left: 10%;
+      text-indent:   0%;
+    }
+    text[class|="hang0_indent1"] {
+      padding-left: 15%;
+      text-indent:  -5%;
+    }
+    text[class|="hang0_indent2"] {
+      padding-left: 20%;
+      text-indent: -10%;
+    }
+    text[class|="hang0_indent3"] {
+      padding-left: 25%;
+      text-indent: -15%;
+    }
+    text[class|="hang0_indent4"] {
+      padding-left: 30%;
+      text-indent: -20%;
+    }
+    text[class|="hang0_indent5"] {
+      padding-left: 35%;
+      text-indent: -25%;
+    }
+    text[class|="hang0_indent6"] {
+      padding-left: 40%;
+      text-indent: -30%;
+    }
+    text[class|="hang0_indent7"] {
+      padding-left: 45%;
+      text-indent: -35%;
+    }
+    text[class|="hang0_indent8"] {
+      padding-left: 50%;
+      text-indent: -40%;
+    }
+    text[class|="hang0_indent9"] {
+      padding-left: 55%;
+      text-indent: -45%;
+    }
+
+    text[class|="hang1_indent0"] {
+      padding-left: 10%;
+      text-indent:   5%;
+    }
+    text[class|="hang1_indent1"] {
+      padding-left: 15%;
+      text-indent:   0%;
+    }
+    text[class|="hang1_indent2"] {
+      padding-left: 20%;
+      text-indent:  -5%;
+    }
+    text[class|="hang1_indent3"] {
+      padding-left: 25%;
+      text-indent: -10%;
+    }
+    text[class|="hang1_indent4"] {
+      padding-left: 30%;
+      text-indent: -15%;
+    }
+    text[class|="hang1_indent5"] {
+      padding-left: 35%;
+      text-indent: -20%;
+    }
+    text[class|="hang1_indent6"] {
+      padding-left: 40%;
+      text-indent: -25%;
+    }
+    text[class|="hang1_indent7"] {
+      padding-left: 45%;
+      text-indent: -30%;
+    }
+    text[class|="hang1_indent8"] {
+      padding-left: 50%;
+      text-indent: -35%;
+    }
+    text[class|="hang1_indent9"] {
+      padding-left: 55%;
+      text-indent: -40%;
+    }
+
+    text[class|="hang2_indent0"] {
+      padding-left: 10%;
+      text-indent:  10%;
+    }
+    text[class|="hang2_indent1"] {
+      padding-left: 15%;
+      text-indent:   5%;
+    }
+    text[class|="hang2_indent2"] {
+      padding-left: 20%;
+      text-indent:   0%;
+    }
+    text[class|="hang2_indent3"] {
+      padding-left: 25%;
+      text-indent:  -5%;
+    }
+    text[class|="hang2_indent4"] {
+      padding-left: 30%;
+      text-indent: -10%;
+    }
+    text[class|="hang2_indent5"] {
+      padding-left: 35%;
+      text-indent: -15%;
+    }
+    text[class|="hang2_indent6"] {
+      padding-left: 40%;
+      text-indent: -20%;
+    }
+    text[class|="hang2_indent7"] {
+      padding-left: 45%;
+      text-indent: -25%;
+    }
+    text[class|="hang2_indent8"] {
+      padding-left: 50%;
+      text-indent: -30%;
+    }
+    text[class|="hang2_indent9"] {
+      padding-left: 55%;
+      text-indent: -35%;
+    }
+
+    text[class|="hang3_indent0"] {
+      padding-left: 10%;
+      text-indent:  15%;
+    }
+    text[class|="hang3_indent1"] {
+      padding-left: 15%;
+      text-indent:  10%;
+    }
+    text[class|="hang3_indent2"] {
+      padding-left: 20%;
+      text-indent:   5%;
+    }
+    text[class|="hang3_indent3"] {
+      padding-left: 25%;
+      text-indent:   0%;
+    }
+    text[class|="hang3_indent4"] {
+      padding-left: 30%;
+      text-indent:  -5%;
+    }
+    text[class|="hang3_indent5"] {
+      padding-left: 35%;
+      text-indent: -10%;
+    }
+    text[class|="hang3_indent6"] {
+      padding-left: 40%;
+      text-indent: -15%;
+    }
+    text[class|="hang3_indent7"] {
+      padding-left: 45%;
+      text-indent: -20%;
+    }
+    text[class|="hang3_indent8"] {
+      padding-left: 50%;
+      text-indent: -25%;
+    }
+    text[class|="hang3_indent9"] {
+      padding-left: 55%;
+      text-indent: -30%;
+    }
+
+    text[class|="hang4_indent0"] {
+      padding-left: 10%;
+      text-indent:  20%;
+    }
+    text[class|="hang4_indent1"] {
+      padding-left: 15%;
+      text-indent:  15%;
+    }
+    text[class|="hang4_indent2"] {
+      padding-left: 20%;
+      text-indent:  10%;
+    }
+    text[class|="hang4_indent3"] {
+      padding-left: 25%;
+      text-indent:   5%;
+    }
+    text[class|="hang4_indent4"] {
+      padding-left: 30%;
+      text-indent:   0%;
+    }
+    text[class|="hang4_indent5"] {
+      padding-left: 35%;
+      text-indent:  -5%;
+    }
+    text[class|="hang4_indent6"] {
+      padding-left: 40%;
+      text-indent: -10%;
+    }
+    text[class|="hang4_indent7"] {
+      padding-left: 45%;
+      text-indent: -15%;
+    }
+    text[class|="hang4_indent8"] {
+      padding-left: 50%;
+      text-indent: -20%;
+    }
+    text[class|="hang4_indent9"] {
+      padding-left: 55%;
+      text-indent: -25%;
+    }
+
+    text[class|="hang5_indent0"] {
+      padding-left: 10%;
+      text-indent:  25%;
+    }
+    text[class|="hang5_indent1"] {
+      padding-left: 15%;
+      text-indent:  20%;
+    }
+    text[class|="hang5_indent2"] {
+      padding-left: 20%;
+      text-indent:  15%;
+    }
+    text[class|="hang5_indent3"] {
+      padding-left: 25%;
+      text-indent:  10%;
+    }
+    text[class|="hang5_indent4"] {
+      padding-left: 30%;
+      text-indent:   5%;
+    }
+    text[class|="hang5_indent5"] {
+      padding-left: 35%;
+      text-indent:   0%;
+    }
+    text[class|="hang5_indent6"] {
+      padding-left: 40%;
+      text-indent:  -5%;
+    }
+    text[class|="hang5_indent7"] {
+      padding-left: 45%;
+      text-indent: -10%;
+    }
+    text[class|="hang5_indent8"] {
+      padding-left: 50%;
+      text-indent: -15%;
+    }
+    text[class|="hang5_indent9"] {
+      padding-left: 55%;
+      text-indent: -20%;
+    }
+
+    text[class|="hang6_indent0"] {
+      padding-left: 10%;
+      text-indent:  30%;
+    }
+    text[class|="hang6_indent1"] {
+      padding-left: 15%;
+      text-indent:  25%;
+    }
+    text[class|="hang6_indent2"] {
+      padding-left: 20%;
+      text-indent:  20%;
+    }
+    text[class|="hang6_indent3"] {
+      padding-left: 25%;
+      text-indent:  15%;
+    }
+    text[class|="hang6_indent4"] {
+      padding-left: 30%;
+      text-indent:  10%;
+    }
+    text[class|="hang6_indent5"] {
+      padding-left: 35%;
+      text-indent:   5%;
+    }
+    text[class|="hang6_indent6"] {
+      padding-left: 40%;
+      text-indent:   0%;
+    }
+    text[class|="hang6_indent7"] {
+      padding-left: 45%;
+      text-indent:  -5%;
+    }
+    text[class|="hang6_indent8"] {
+      padding-left: 50%;
+      text-indent: -10%;
+    }
+    text[class|="hang6_indent9"] {
+      padding-left: 55%;
+      text-indent: -15%;
+    }
+
+    text[class|="hang7_indent0"] {
+      padding-left: 10%;
+      text-indent:  35%;
+    }
+    text[class|="hang7_indent1"] {
+      padding-left: 15%;
+      text-indent:  30%;
+    }
+    text[class|="hang7_indent2"] {
+      padding-left: 20%;
+      text-indent:  25%;
+    }
+    text[class|="hang7_indent3"] {
+      padding-left: 25%;
+      text-indent:  20%;
+    }
+    text[class|="hang7_indent4"] {
+      padding-left: 30%;
+      text-indent:  15%;
+    }
+    text[class|="hang7_indent5"] {
+      padding-left: 35%;
+      text-indent:  10%;
+    }
+    text[class|="hang7_indent6"] {
+      padding-left: 40%;
+      text-indent:   5%;
+    }
+    text[class|="hang7_indent7"] {
+      padding-left: 45%;
+      text-indent:   0%;
+    }
+    text[class|="hang7_indent8"] {
+      padding-left: 50%;
+      text-indent:  -5%;
+    }
+    text[class|="hang7_indent9"] {
+      padding-left: 55%;
+      text-indent: -10%;
+    }
+
+    text[class|="hang8_indent0"] {
+      padding-left: 10%;
+      text-indent:  40%;
+    }
+    text[class|="hang8_indent1"] {
+      padding-left: 15%;
+      text-indent:  35%;
+    }
+    text[class|="hang8_indent2"] {
+      padding-left: 20%;
+      text-indent:  30%;
+    }
+    text[class|="hang8_indent3"] {
+      padding-left: 25%;
+      text-indent:  25%;
+    }
+    text[class|="hang8_indent4"] {
+      padding-left: 30%;
+      text-indent:  20%;
+    }
+    text[class|="hang8_indent5"] {
+      padding-left: 35%;
+      text-indent:  15%;
+    }
+    text[class|="hang8_indent6"] {
+      padding-left: 40%;
+      text-indent:  10%;
+    }
+    text[class|="hang8_indent7"] {
+      padding-left: 45%;
+      text-indent:   5%;
+    }
+    text[class|="hang8_indent8"] {
+      padding-left: 50%;
+      text-indent:   0%;
+    }
+    text[class|="hang8_indent9"] {
+      padding-left: 55%;
+      text-indent:  -5%;
+    }
+
+    text[class|="hang9_indent0"] {
+      padding-left: 10%;
+      text-indent:  45%;
+    }
+    text[class|="hang9_indent1"] {
+      padding-left: 15%;
+      text-indent:  40%;
+    }
+    text[class|="hang9_indent2"] {
+      padding-left: 20%;
+      text-indent:  35%;
+    }
+    text[class|="hang9_indent3"] {
+      padding-left: 25%;
+      text-indent:  30%;
+    }
+    text[class|="hang9_indent4"] {
+      padding-left: 30%;
+      text-indent:  25%;
+    }
+    text[class|="hang9_indent5"] {
+      padding-left: 35%;
+      text-indent:  20%;
+    }
+    text[class|="hang9_indent6"] {
+      padding-left: 40%;
+      text-indent:  15%;
+    }
+    text[class|="hang9_indent7"] {
+      padding-left: 45%;
+      text-indent:  10%;
+    }
+    text[class|="hang9_indent8"] {
+      padding-left: 50%;
+      text-indent:   5%;
+    }
+    text[class|="hang9_indent9"] {
+      padding-left: 55%;
+      text-indent:   0%;
+    }
+
+    text[class|="indent_bullet"] {
+      text-indent: 0%;
+    }
+    text[class|="indent_bullet0"] {
+      text-indent: 0%;
     }
     text[class|="indent_bullet1"] {
-      margin-left: 10%;
+      padding-left: 10%;
     }
     text[class|="indent_bullet2"] {
-      margin-left: 15%;
+      padding-left: 15%;
     }
     text[class|="indent_bullet3"] {
-      margin-left: 20%;
+      padding-left: 20%;
     }
     text[class|="indent_bullet4"] {
-      margin-left: 25%;
+      padding-left: 25%;
     }
     text[class|="indent_bullet5"] {
-      margin-left: 30%;
+      padding-left: 30%;
     }
     text[class|="indent_bullet6"] {
-      margin-left: 35%;
+      padding-left: 35%;
     }
     text[class|="indent_bullet7"] {
-      margin-left: 40%;
+      padding-left: 40%;
     }
     text[class|="indent_bullet8"] {
-      margin-left: 45%;
+      padding-left: 45%;
     }
     text[class|="indent_bullet9"] {
-      margin-left: 50%;
+      padding-left: 50%;
     }
     text[class|="verse"], text[class|="block"], text[class|="group"], text[class|="code"] {
       text-align: left;
