@@ -240,7 +240,7 @@ module SiSU_DAL
       unless @opt.cmd =~/q/
         tell=(@opt.cmd=~/[vVM]/) \
         ? SiSU_Screen::Ansi.new(@opt.cmd,'Document Abstraction') \
-        : SiSU_Screen::Ansi.new(@opt.cmd,'Document Abstraction',@opt.fns)
+        : SiSU_Screen::Ansi.new(@opt.cmd,'Document Abstraction',"[#{@opt.f_pth[:lng_is]}] #{@opt.fns}")
         tell.green_title_hi
       end
       fn=(@fnx && @fnx =~/\.ss[tmi]$/) \
