@@ -116,6 +116,7 @@ module SiSU_DB_create
             #{column.creator_author.create_column}
             #{column.creator_author_honorific.create_column}
             #{column.creator_author_nationality.create_column}
+            #{column.creator_editor.create_column}
             #{column.creator_contributor.create_column}
             #{column.creator_illustrator.create_column}
             #{column.creator_photographer.create_column}
@@ -375,6 +376,7 @@ module SiSU_DB_create
           %{#{column.creator_author.column_comment}},
           %{#{column.creator_author_honorific.column_comment}},
           %{#{column.creator_author_nationality.column_comment}},
+          %{#{column.creator_editor.column_comment}},
           %{#{column.creator_contributor.column_comment}},
           %{#{column.creator_illustrator.column_comment}},
           %{#{column.creator_photographer.column_comment}},
