@@ -393,8 +393,16 @@ module SiSU_DB_import
                 SiSU_Format_Shared::CSS_Format.new(@md,data).html_table
               elsif data.is=='code'
                 SiSU_Format_Shared::CSS_Format.new(@md,data).code
-              elsif defined? data.indent and data.indent =~/[1-9]/
+              elsif defined? data.indent \
+              and defined? data.hang \
+              and data.indent =~/[1-9]/ \
+              and data.indent == data.hang
                 SiSU_Format_Shared::CSS_Format.new(@md,data).indent(data.indent)
+              elsif defined? data.indent \
+              and defined? data.hang \
+              and data.hang =~/[0-9]/ \
+              and data.indent != data.hang
+                SiSU_Format_Shared::CSS_Format.new(@md,data).hang_indent(data.hang,data.indent)
               else
                 SiSU_Format_Shared::CSS_Format.new(@md,data).norm
               end
