@@ -77,7 +77,7 @@ module SiSU_Digest_view
         unless @opt.cmd =~/q/
           tool=(@opt.cmd =~/[MVv]/) \
           ? "#{@env.program.text_editor} file://#{@md.file.output_path.hash_digest.dir}/#{@md.file.base_filename.hash_digest}" \
-          : @opt.fns
+          : "[#{@opt.f_pth[:lng_is]}] #{@opt.fns}"
           @opt.cmd=~/[MVvz]/ \
           ? SiSU_Screen::Ansi.new(@opt.cmd,"Document #{@dg} Digests",tool).green_hi_blue \
           : SiSU_Screen::Ansi.new(@opt.cmd,"Document #{@dg} Digests",tool).green_title_hi
