@@ -87,8 +87,8 @@ module SiSU_Embedded
     def images
       src="#{@base_src_dir}/_sisu/image"
       src_img='_sisu/image'
-      ldest="#{@env.path.webserv}/#{@env.path.stub_pwd}"
-      img_dir="#{@env.path.webserv}/#{@env.path.stub_pwd}/_sisu/image"
+      ldest=@env.path.output
+      img_dir="#{@env.path.output}/_sisu/image"
       @rhost.each do |remote_conn|
         rdest="#{remote_conn[:name]}/#{@env.path.stub_pwd}/_sisu/image"
         remote_rel=remote_conn[:name] + '/' + @f.output_path.stub.rcp
