@@ -86,7 +86,7 @@ module SiSU_EPUB
         loc=@env.path.url.output_tell
         unless @opt.cmd =~/q/
           tool=if @opt.cmd =~/[MVvz]/; "#{@env.program.epub_viewer} #{@md.file.output_path.epub.dir}/#{@md.file.base_filename.epub}"
-          else                      @opt.fns
+          else                      "[#{@opt.f_pth[:lng_is]}] #{@opt.fns}"
           end
           @opt.cmd=~/[MVvz]/ \
           ? SiSU_Screen::Ansi.new(@opt.cmd,'EPUB',tool).green_hi_blue \
