@@ -161,6 +161,7 @@ module SiSU_EPUB_Format
     margin-right: 2em;
     margin-top: 10px;
     margin-bottom: 0px;
+    padding-left: 0em;
     text-indent: 0mm;
   }
   p, h0, h1, h2, h3, h4, h5, h6 {
@@ -177,15 +178,426 @@ module SiSU_EPUB_Format
     margin-bottom: 3px;
   }
   p.norm { }
-  p.i1 {margin-left: 1em;}
-  p.i2 {margin-left: 2em;}
-  p.i3 {margin-left: 3em;}
-  p.i4 {margin-left: 4em;}
-  p.i5 {margin-left: 5em;}
-  p.i6 {margin-left: 6em;}
-  p.i7 {margin-left: 7em;}
-  p.i8 {margin-left: 8em;}
-  p.i9 {margin-left: 9em;}
+  p.i1 {padding-left: 1em;}
+  p.i2 {padding-left: 2em;}
+  p.i3 {padding-left: 3em;}
+  p.i4 {padding-left: 4em;}
+  p.i5 {padding-left: 5em;}
+  p.i6 {padding-left: 6em;}
+  p.i7 {padding-left: 7em;}
+  p.i8 {padding-left: 8em;}
+  p.i9 {padding-left: 9em;}
+
+  p.h0i0 {
+    padding-left: 0em;
+    text-indent:  0em;
+  }
+  p.h0i1 {
+    padding-left: 1em;
+    text-indent: -1em;
+  }
+  p.h0i2 {
+    padding-left: 2em;
+    text-indent: -2em;
+  }
+  p.h0i3 {
+    padding-left: 3em;
+    text-indent: -3em;
+  }
+  p.h0i4 {
+    padding-left: 4em;
+    text-indent: -4em;
+  }
+  p.h0i5 {
+    padding-left: 5em;
+    text-indent: -5em;
+  }
+  p.h0i6 {
+    padding-left: 6em;
+    text-indent: -6em;
+  }
+  p.h0i7 {
+    padding-left: 7em;
+    text-indent: -7em;
+  }
+  p.h0i8 {
+    padding-left: 8em;
+    text-indent: -8em;
+  }
+  p.h0i9 {
+    padding-left: 9em;
+    text-indent: -9em;
+  }
+
+  p.h1i0 {
+    padding-left: 0em;
+    text-indent:  1em;
+  }
+  p.h1i1 {
+    padding-left: 1em;
+    text-indent:  0em;
+  }
+  p.h1i2 {
+    padding-left: 2em;
+    text-indent: -1em;
+  }
+  p.h1i3 {
+    padding-left: 3em;
+    text-indent: -2em;
+  }
+  p.h1i4 {
+    padding-left: 4em;
+    text-indent: -3em;
+  }
+  p.h1i5 {
+    padding-left: 5em;
+    text-indent: -4em;
+  }
+  p.h1i6 {
+    padding-left: 6em;
+    text-indent: -5em;
+  }
+  p.h1i7 {
+    padding-left: 7em;
+    text-indent: -6em;
+  }
+  p.h1i8 {
+    padding-left: 8em;
+    text-indent: -7em;
+  }
+  p.h1i9 {
+    padding-left: 9em;
+    text-indent: -8em;
+  }
+
+  p.h2i0 {
+    padding-left: 0em;
+    text-indent:  2em;
+  }
+  p.h2i1 {
+    padding-left: 1em;
+    text-indent:  1em;
+  }
+  p.h2i2 {
+    padding-left: 2em;
+    text-indent:  0em;
+  }
+  p.h2i3 {
+    padding-left: 3em;
+    text-indent: -1em;
+  }
+  p.h2i4 {
+    padding-left: 4em;
+    text-indent: -2em;
+  }
+  p.h2i5 {
+    padding-left: 5em;
+    text-indent: -3em;
+  }
+  p.h2i6 {
+    padding-left: 6em;
+    text-indent: -4em;
+  }
+  p.h2i7 {
+    padding-left: 7em;
+    text-indent: -5em;
+  }
+  p.h2i8 {
+    padding-left: 8em;
+    text-indent: -6em;
+  }
+  p.h2i9 {
+    padding-left: 9em;
+    text-indent: -7em;
+  }
+
+  p.h3i0 {
+    padding-left: 0em;
+    text-indent:  3em;
+  }
+  p.h3i1 {
+    padding-left: 1em;
+    text-indent:  2em;
+  }
+  p.h3i2 {
+    padding-left: 2em;
+    text-indent:  1em;
+  }
+  p.h3i3 {
+    padding-left: 3em;
+    text-indent:  0em;
+  }
+  p.h3i4 {
+    padding-left: 4em;
+    text-indent: -1em;
+  }
+  p.h3i5 {
+    padding-left: 5em;
+    text-indent: -2em;
+  }
+  p.h3i6 {
+    padding-left: 6em;
+    text-indent: -3em;
+  }
+  p.h3i7 {
+    padding-left: 7em;
+    text-indent: -4em;
+  }
+  p.h3i8 {
+    padding-left: 8em;
+    text-indent: -5em;
+  }
+  p.h3i9 {
+    padding-left: 9em;
+    text-indent: -6em;
+  }
+
+  p.h4i0 {
+    padding-left: 0em;
+    text-indent:  4em;
+  }
+  p.h4i1 {
+    padding-left: 1em;
+    text-indent:  3em;
+  }
+  p.h4i2 {
+    padding-left: 2em;
+    text-indent:  2em;
+  }
+  p.h4i3 {
+    padding-left: 3em;
+    text-indent:  1em;
+  }
+  p.h4i4 {
+    padding-left: 4em;
+    text-indent:  0em;
+  }
+  p.h4i5 {
+    padding-left: 5em;
+    text-indent: -1em;
+  }
+  p.h4i6 {
+    padding-left: 6em;
+    text-indent: -2em;
+  }
+  p.h4i7 {
+    padding-left: 7em;
+    text-indent: -3em;
+  }
+  p.h4i8 {
+    padding-left: 8em;
+    text-indent: -4em;
+  }
+  p.h4i9 {
+    padding-left: 9em;
+    text-indent: -5em;
+  }
+
+  p.h5i0 {
+    padding-left: 0em;
+    text-indent:  5em;
+  }
+  p.h5i1 {
+    padding-left: 1em;
+    text-indent:  4em;
+  }
+  p.h5i2 {
+    padding-left: 2em;
+    text-indent:  3em;
+  }
+  p.h5i3 {
+    padding-left: 3em;
+    text-indent:  2em;
+  }
+  p.h5i4 {
+    padding-left: 4em;
+    text-indent:  1em;
+  }
+  p.h5i5 {
+    padding-left: 5em;
+    text-indent:  0em;
+  }
+  p.h5i6 {
+    padding-left: 6em;
+    text-indent: -1em;
+  }
+  p.h5i7 {
+    padding-left: 7em;
+    text-indent: -2em;
+  }
+  p.h5i8 {
+    padding-left: 8em;
+    text-indent: -3em;
+  }
+  p.h5i9 {
+    padding-left: 9em;
+    text-indent: -4em;
+  }
+
+  p.h6i0 {
+    padding-left: 0em;
+    text-indent:  6em;
+  }
+  p.h6i1 {
+    padding-left: 1em;
+    text-indent:  5em;
+  }
+  p.h6i2 {
+    padding-left: 2em;
+    text-indent:  4em;
+  }
+  p.h6i3 {
+    padding-left: 3em;
+    text-indent:  3em;
+  }
+  p.h6i4 {
+    padding-left: 4em;
+    text-indent:  2em;
+  }
+  p.h6i5 {
+    padding-left: 5em;
+    text-indent:  1em;
+  }
+  p.h6i6 {
+    padding-left: 6em;
+    text-indent:  0em;
+  }
+  p.h6i7 {
+    padding-left: 7em;
+    text-indent: -1em;
+  }
+  p.h6i8 {
+    padding-left: 8em;
+    text-indent: -2em;
+  }
+  p.h6i9 {
+    padding-left: 9em;
+    text-indent: -3em;
+  }
+
+  p.h7i0 {
+    padding-left: 0em;
+    text-indent:  7em;
+  }
+  p.h7i1 {
+    padding-left: 1em;
+    text-indent:  6em;
+  }
+  p.h7i2 {
+    padding-left: 2em;
+    text-indent:  5em;
+  }
+  p.h7i3 {
+    padding-left: 3em;
+    text-indent:  4em;
+  }
+  p.h7i4 {
+    padding-left: 4em;
+    text-indent:  3em;
+  }
+  p.h7i5 {
+    padding-left: 5em;
+    text-indent:  2em;
+  }
+  p.h7i6 {
+    padding-left: 6em;
+    text-indent:  1em;
+  }
+  p.h7i7 {
+    padding-left: 7em;
+    text-indent:  0em;
+  }
+  p.h7i8 {
+    padding-left: 8em;
+    text-indent: -1em;
+  }
+  p.h7i9 {
+    padding-left: 9em;
+    text-indent: -2em;
+  }
+
+  p.h8i0 {
+    padding-left: 0em;
+    text-indent:  8em;
+  }
+  p.h8i1 {
+    padding-left: 1em;
+    text-indent:  7em;
+  }
+  p.h8i2 {
+    padding-left: 2em;
+    text-indent:  6em;
+  }
+  p.h8i3 {
+    padding-left: 3em;
+    text-indent:  5em;
+  }
+  p.h8i4 {
+    padding-left: 4em;
+    text-indent:  4em;
+  }
+  p.h8i5 {
+    padding-left: 5em;
+    text-indent:  3em;
+  }
+  p.h8i6 {
+    padding-left: 6em;
+    text-indent:  2em;
+  }
+  p.h8i7 {
+    padding-left: 7em;
+    text-indent:  1em;
+  }
+  p.h8i8 {
+    padding-left: 8em;
+    text-indent:  0em;
+  }
+  p.h8i9 {
+    padding-left: 9em;
+    text-indent: -1em;
+  }
+
+  p.h9i0 {
+    padding-left: 0em;
+    text-indent:  9em;
+  }
+  p.h9i1 {
+    padding-left: 1em;
+    text-indent:  8em;
+  }
+  p.h9i2 {
+    padding-left: 2em;
+    text-indent:  7em;
+  }
+  p.h9i3 {
+    padding-left: 3em;
+    text-indent:  6em;
+  }
+  p.h9i4 {
+    padding-left: 4em;
+    text-indent:  5em;
+  }
+  p.h9i5 {
+    padding-left: 5em;
+    text-indent:  4em;
+  }
+  p.h9i6 {
+    padding-left: 6em;
+    text-indent:  3em;
+  }
+  p.h9i7 {
+    padding-left: 7em;
+    text-indent:  2em;
+  }
+  p.h9i8 {
+    padding-left: 8em;
+    text-indent:  1em;
+  }
+  p.h9i9 {
+    padding-left: 9em;
+    text-indent:  0em;
+  }
+
 
   p.it0 {
     margin-left: 0em;
@@ -1037,16 +1449,112 @@ WOK
       def metadata #metadata dc
         author=if defined? @md.creator.author \
         and @md.creator.author =~/\S+/
-          x=@md.creator.author.gsub!(/</,'&lt;'); @md.creator.author.gsub!(/>/,'&gt;')
-          @md.creator.author.gsub!(/&lt;br(?: \/)?&gt;/,'<br />')
-          %{\n    <dc:creator opf:file-as="#{x}" opf:role="aut">#{x}</dc:creator>}
+          m=''
+          @md.creator.author_detail.each do |x|
+            surname=x[:the] \
+            ? x[:the] \
+            : ''
+            other_names=x[:others] \
+            ? ', ' + x[:others] \
+            : ''
+            m=(m.empty?) \
+            ? (surname + other_names) \
+            : (m + '; ' + surname + ', ' + other_names)
+            m.gsub!(/</,'&lt;'); m.gsub!(/>/,'&gt;')
+            m.gsub!(/&lt;br(?: \/)?&gt;/,';')
+          end
+          x=@md.creator.author.dup
+          x.gsub!(/</,'&lt;'); x.gsub!(/>/,'&gt;')
+          x.gsub!(/&lt;br(?: \/)?&gt;/,'<br />')
+          %{\n    <dc:creator opf:file-as="#{m}" opf:role="aut">#{x}</dc:creator>}
+        else ''
+        end
+        editor=if defined? @md.creator.editor \
+        and @md.creator.editor =~/\S+/
+          m=''
+          @md.creator.editor_detail.each do |x|
+            surname=x[:the] \
+            ? x[:the] \
+            : ''
+            other_names=x[:others] \
+            ? ', ' + x[:others] \
+            : ''
+            m=(m.empty?) \
+            ? (surname + other_names) \
+            : (m + '; ' + surname + ', ' + other_names)
+            m.gsub!(/</,'&lt;'); m.gsub!(/>/,'&gt;')
+            m.gsub!(/&lt;br(?: \/)?&gt;/,';')
+          end
+          x=@md.creator.editor.dup
+          x.gsub!(/</,'&lt;'); x.gsub!(/>/,'&gt;')
+          x.gsub!(/&lt;br(?: \/)?&gt;/,'<br />')
+          %{\n    <dc:creator opf:file-as="#{m}" opf:role="edt">#{x}</dc:creator>}
+        else ''
+        end
+        translator=if defined? @md.creator.translator \
+        and @md.creator.translator =~/\S+/
+          m=''
+          @md.creator.translator_detail.each do |x|
+            surname=x[:the] \
+            ? x[:the] \
+            : ''
+            other_names=x[:others] \
+            ? ', ' + x[:others] \
+            : ''
+            m=(m.empty?) \
+            ? (surname + other_names) \
+            : (m + '; ' + surname + ', ' + other_names)
+            m.gsub!(/</,'&lt;'); m.gsub!(/>/,'&gt;')
+            m.gsub!(/&lt;br(?: \/)?&gt;/,';')
+          end
+          x=@md.creator.translator.dup
+          x.gsub!(/</,'&lt;'); x.gsub!(/>/,'&gt;')
+          x.gsub!(/&lt;br(?: \/)?&gt;/,'<br />')
+          %{\n    <dc:creator opf:file-as="#{m}" opf:role="trl">#{x}</dc:creator>}
         else ''
         end
         illustrator=if defined? @md.creator.illustrator \
         and @md.creator.illustrator =~/\S+/
-          x=@md.creator.illustrator.gsub!(/</,'&lt;'); @md.creator.illustrator.gsub!(/>/,'&gt;')
-          @md.creator.illustrator.gsub!(/&lt;br(?: \/)?&gt;/,'<br />')
-          %{\n    <dc:creator opf:file-as="#{x}" opf:role="ill">#{x}</dc:creator>}
+          m=''
+          @md.creator.illustrator_detail.each do |x|
+            surname=x[:the] \
+            ? x[:the] \
+            : ''
+            other_names=x[:others] \
+            ? ', ' + x[:others] \
+            : ''
+            m=(m.empty?) \
+            ? (surname + other_names) \
+            : (m + '; ' + surname + ', ' + other_names)
+            m.gsub!(/</,'&lt;'); m.gsub!(/>/,'&gt;')
+            m.gsub!(/&lt;br(?: \/)?&gt;/,';')
+          end
+          x=@md.creator.illustrator.dup
+          x.gsub!(/</,'&lt;'); x.gsub!(/>/,'&gt;')
+          x.gsub!(/&lt;br(?: \/)?&gt;/,'<br />')
+          %{\n    <dc:creator opf:file-as="#{m}" opf:role="ill">#{x}</dc:creator>}
+        else ''
+        end
+        date_published=if defined? @md.date.published \
+        and @md.date.published =~/\S+/
+          x=@md.date.published.dup
+          x.gsub!(/</,'&lt;'); x.gsub!(/>/,'&gt;')
+          x.gsub!(/&lt;br(?: \/)?&gt;/,'<br />')
+          %{\n    <dc:date opf:event="published">#{x}</dc:date>}
+        else ''
+        end
+        subject=if defined? @md.classify.subject \
+        and @md.classify.subject =~/\S+/
+          x=@md.classify.subject.dup
+          x.gsub!(/</,'&lt;'); x.gsub!(/>/,'&gt;')
+          x.gsub!(/&lt;br(?: \/)?&gt;/,'<br />')
+          %{\n    <dc:subject>#{x}</dc:subject>}
+        else ''
+        end
+        language=if defined? @md.opt.lng \
+        and @md.opt.lng =~/\S+/
+          language=@md.opt.lng.gsub(/<br>/,'<br />')
+          %{\n    <dc:language>#{language}</dc:language>}
         else ''
         end
         rights=if defined? @md.rights.all \
@@ -1058,10 +1566,8 @@ WOK
         <<WOK
   <metadata xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:opf="http://www.idpf.org/2007/opf">
     <dc:title>#{@md.title.full}</dc:title>
-    #{author}#{illustrator}
-    <dc:language>en-US</dc:language>
+    #{author}#{editor}#{translator}#{illustrator}#{language}#{date_published}#{subject}#{rights}
     <dc:identifier id="bookid">...</dc:identifier>
-    #{rights}
     <dc:identifier id="EPB-UUID">urn:uuid:#{@md.dgst[1]}</dc:identifier>
   </metadata>
 WOK
