@@ -88,7 +88,7 @@ module SiSU_HTML
         loc=@env.url.output_tell
         unless @opt.cmd =~/q/
           tool=if @opt.cmd =~/[MVvz]/; "#{@env.program.web_browser} file://#{@md.file.output_path.html_seg.dir}/#{@md.file.base_filename.html_segtoc}"
-          else                          @opt.fns
+          else                          "[#{@opt.f_pth[:lng_is]}] #{@opt.fns}"
           end
           @opt.cmd=~/[MVvz]/ \
           ? SiSU_Screen::Ansi.new(@opt.cmd,'HTML',tool).green_hi_blue \
