@@ -299,7 +299,7 @@ WOK
 <p />}
     end
     def seg_head_navigation_band(type='')
-      firstseg=%{<a href="#{@md.fnl[:pre]}#{@md.firstseg}#{@md.fnl[:mid]}#{Sfx[:html]}#{@md.fnl[:post]}" target="_top" alt="-&gt;">
+      firstseg=%{<a href="#{@md.firstseg}#{@md.lang_code_insert}#{Sfx[:html]}" target="_top" alt="-&gt;">
       #{@vz.png_nav_nxt}
     </a>} if @md.firstseg =~/\S+/
       %{<table summary="table of contents segment navigation band" id="toc" width="100%" bgcolor=#{@vz.color_band1}>
@@ -318,7 +318,7 @@ WOK
       if type=~/pdf/
         @tocband_segtoc=make_scroll_seg_pdf
       end
-      firstseg=%{<a href="#{@md.fnl[:pre]}#{@md.firstseg}#{@md.fnl[:mid]}#{Sfx[:html]}#{@md.fnl[:post]}" target="_top" alt="-&gt;">
+      firstseg=%{<a href="#{@md.firstseg}#{@md.lang_code_insert}#{Sfx[:html]}" target="_top" alt="-&gt;">
       #{@vz.png_nav_nxt}
     </a>} if @md.firstseg =~/\S+/
       %{<table summary="table of contents segment navigation band" id="toc" width="100%" bgcolor=#{@vz.color_band1}>
@@ -646,9 +646,9 @@ WOK
     def title_banner(title,subtitle,creator)
     end
     def dot_control_pre_next
-      pre="#{@md.fnl[:pre]}#{@seg_name_html[@seg_name_html_tracker-1]}#{@md.fnl[:mid]}#{Sfx[:html]}#{@md.fnl[:post]}"
-      up="#{@md.fnl[:pre]}#{@toc}#{@md.fnl[:mid]}#{Sfx[:html]}#{@md.fnl[:post]}"
-      nxt="#{@md.fnl[:pre]}#{@seg_name_html[@seg_name_html_tracker+1]}#{@md.fnl[:mid]}#{Sfx[:html]}#{@md.fnl[:post]}"
+      pre="#{@seg_name_html[@seg_name_html_tracker-1]}#{@md.lang_code_insert}#{Sfx[:html]}"
+      up="#{@toc}#{@md.lang_code_insert}#{Sfx[:html]}"
+      nxt="#{@seg_name_html[@seg_name_html_tracker+1]}#{@md.lang_code_insert}#{Sfx[:html]}"
       if nxt=~/sisu_manifest\.html/
         @file=SiSU_Env::SiSU_file.new(@md) if @md
         if @file.output_dir_structure.by_language_code? \
@@ -674,8 +674,8 @@ WOK
 #{@vz.table_close}}
     end
     def dot_control_pre
-      pre="#{@md.fnl[:pre]}#{@seg_name_html[@seg_name_html_tracker-2]}#{@md.fnl[:mid]}#{Sfx[:html]}#{@md.fnl[:post]}"
-      up="#{@md.fnl[:pre]}#{@toc}#{@md.fnl[:mid]}#{Sfx[:html]}#{@md.fnl[:post]}"
+      pre="#{@seg_name_html[@seg_name_html_tracker-2]}#{@md.lang_code_insert}#{Sfx[:html]}"
+      up="#{@toc}#{@md.lang_code_insert}#{Sfx[:html]}"
       nxt="#{@md.fn[:toc]}"
       %{<table summary="segment hidden control pre" width="100%" border="0" cellpadding="0" bgcolor=#{@vz.color_grey_pale} align="center">
 <tr><td align="left">
@@ -697,17 +697,17 @@ WOK
     def toc_nav(f_pre=false,f_nxt=false,use=1)
       pre=nxt=''
       toc=%{<td align="center" bgcolor=#{@vz.color_band1}>
-  <a href="#{@md.fnl[:pre]}#{@toc}#{@md.fnl[:mid]}#{Sfx[:html]}#{@md.fnl[:post]}" target="_top" #{@vz.js_toc}>
+  <a href="#{@toc}#{@md.lang_code_insert}#{Sfx[:html]}" target="_top" #{@vz.js_toc}>
     #{@vz.png_nav_toc}
   </a>
 </td>}
       pre=%{<td align="center" bgcolor=#{@vz.color_band1}>
-  <a href="#{@md.fnl[:pre]}#{@seg_name_html[@seg_name_html_tracker-use]}#{@md.fnl[:mid]}#{Sfx[:html]}#{@md.fnl[:post]}" target="_top" #{@vz.js_prev}>
+  <a href="#{@seg_name_html[@seg_name_html_tracker-use]}#{@md.lang_code_insert}#{Sfx[:html]}" target="_top" #{@vz.js_prev}>
     #{@vz.png_nav_pre}
   </a>
 </td>} if f_pre==true
       nxt=%{<td align="center" bgcolor=#{@vz.color_band1}>
-  <a href="#{@md.fnl[:pre]}#{@seg_name_html[@seg_name_html_tracker+1]}#{@md.fnl[:mid]}#{Sfx[:html]}#{@md.fnl[:post]}" target="_top" #{@vz.js_next}>
+  <a href="#{@seg_name_html[@seg_name_html_tracker+1]}#{@md.lang_code_insert}#{Sfx[:html]}" target="_top" #{@vz.js_next}>
     #{@vz.png_nav_nxt}
   </a>
 </td>} if f_nxt==true
@@ -1281,7 +1281,7 @@ WOK
       fn='doc' if fn.to_s.empty? #you may wish to reconsider, sends to 'doc' where no segment info
       %{
   <p class="endnote">
-    #{@endnote_part_a}#{@md.fnl[:pre]}#{fn}#{@md.fnl[:mid]}#{Sfx[:html]}#{@md.fnl[:post]}#{@endnote_part_b}
+    #{@endnote_part_a}#{fn}#{@md.lang_code_insert}#{Sfx[:html]}#{@endnote_part_b}
   </p>
 }
     end
