@@ -389,16 +389,22 @@ module SiSU_HTML_seg
             end
           elsif dob.is=='para'
             if dob.indent \
-            and dob.indent =~/[1-9]/
+            and dob.hang \
+            and dob.indent =~/[0-9]/ \
+            and dob.hang =~/[0-9]/
               if dob.bullet_
-                sto.format('li',"i#{dob.indent}")
-              else sto.format('p',"i#{dob.indent}")
-              end
-            else
-              if dob.bullet_
-                sto.format('li','bullet')
+                if dob.indent =~/[1-9]/
+                  sto.format('li',"i#{dob.indent}")
+                else
+                  sto.format('li','bullet')
+                end
+              elsif dob.indent == dob.hang
+                sto.format('p',"i#{dob.indent}")
+              elsif dob.indent != dob.hang
+                sto.format('p',"h#{dob.hang}i#{dob.indent}")
               else sto.para
               end
+            else sto.para
             end
           end
         elsif dob.is=='block'
