@@ -157,6 +157,7 @@ module SiSU
                   when /^xml_scaffold$/;    SiSU_XML_scaffold::Source.new(@opt).read     # -k     xml_scaffold.rb
                   when /^embedded$/;        SiSU_Embedded::Source.new(@opt).read         # -m     embedded.rb (image and other content) #check
                   when /^manifest$/;        SiSU_Manifest::Source.new(@opt).read         # -y     manifest.rb
+                  when /^qrcode$/;          SiSU_QRcode::Source.new(@opt).read           # -Q     qrcode.rb
                   when /^sitemaps$/;        SiSU_Sitemaps::Source.new(@opt).read         # -Y     sitemaps.rb
                   when /^zap$/;             SiSU_Zap::Source.new(@opt).read              # -Z     zap.rb
                   when /^dbi$/;             SiSU_DBI::SiSU_SQL.new(@opt).connect         # -D -d  dbi.rb
@@ -398,6 +399,9 @@ p "here #{__FILE__} #{__LINE__}" if @opt =~/M/
             op('share_src_kdissert','kdissert (kdi)')      #% -S share kdissert source
           end
         end
+        if @opt.act[:qrcode]                               #% --qrcode, -Q
+          op('qrcode','QRcode')
+        end
         if @opt.act[:hash_digests]                         #% --hash-digests, -N digest tree
           op('digests','digests')
         end
