@@ -415,6 +415,33 @@ module SiSU_Manifest
           published_languages(id,file)
         end
       end
+      def qrc_image
+        pth="#{@env.path.webserv}/#{@env.path.stub_pwd}/_sisu/image"
+        fn=@f.base_filename.manifest_txt
+        #fix relative path for different output structures
+        img_md="../../_sisu/image/qrc_md.#{fn}.png"
+        img_title="../../_sisu/image/qrc_title.#{fn}.png"
+        if FileTest.file?("#{pth}/qrc_md.#{fn}.png")==true
+          @manifest[:html] <<<<WOK
+<tr><td class="left">
+  <p class="tiny">QR code SiSU document metadata:</p>
+  <p class="tiny">
+    <img border="0" src="#{img_md}" alt="qrcode metadata" />
+  </p>
+</td></tr>
+WOK
+        end
+        if FileTest.file?("#{pth}/qrc_title.#{fn}.png")==true
+          @manifest[:html] <<<<WOK
+<tr><td class="left">
+  <p class="tiny">QR code document title info:</p>
+  <p class="tiny">
+    <img border="0" src="#{img_title}" alt="qrcode title" />
+  </p>
+</td></tr>
+WOK
+        end
+      end
       def source_tests
         if @md.fns =~/\.ssm\.sst$/                                                  #% decide whether to extract and include requested/required documents
           req=@md.fns
@@ -463,6 +490,11 @@ module SiSU_Manifest
           id,info=@translate.author,@md.creator.author
           metadata(id,info)
         end
+        if defined? @md.creator.editor \
+        and @md.creator.editor=~/\S+/
+          id,info=@translate.editor,@md.creator.editor
+          metadata(id,info)
+        end
         if defined? @md.creator.contributor \
         and @md.creator.contributor=~/\S+/
           id,info=@translate.contributor,@md.creator.contributor
@@ -813,6 +845,7 @@ WOK
 
 WOK
           language_versions
+          qrc_image
           @manifest[:html] <<<<WOK
 </table>
 </div>
