@@ -202,11 +202,15 @@ WOK
         or dob.is=='heading'
           paragraph=dob.obj
           if dob.is=='para'
-            if dob.indent =~/[1-9]/
+            if dob.indent =~/[1-9]/ \
+            and dob.indent == dob.hang
               util=if dob.bullet_
                 SiSU_text_utils::Wrap.new("* #{paragraph}",78,dob.indent.to_i*2)
               else SiSU_text_utils::Wrap.new(paragraph,78,dob.indent.to_i*2)
               end
+            elsif dob.hang =~/[0-9]/ \
+            and dob.indent != dob.hang                     # NOT yet implemented
+              util=SiSU_text_utils::Wrap.new(paragraph,78,dob.indent.to_i*2)
             else
               util=if dob.bullet_
                 SiSU_text_utils::Wrap.new("* #{paragraph}",78,0)
