@@ -309,6 +309,7 @@ module SiSU_commandline
           when /^--(?:po4a|pot?)$/;                          c=c+'P'
           when /^--(?:termsheet)$/;                          c=c+'T'
           when /^--(?:manifest)$/;                           c=c+'y'
+          when /^--(?:qrcode)$/;                             c=c+'Q'
           when /^--(?:sqlite)$/;                             c=c+'d'
           when /^--(?:pg|pg?sql|postgresql)$/;               c=c+'D'
           when /^--(?:remote|rsync)$/;                       c=c+'R'
@@ -551,6 +552,11 @@ module SiSU_commandline
         true
       else false
       end
+      act[:qrcode]=if cmd =~/Q/ \
+      or mod.inspect =~/"--qrcode"/
+        true
+      else false
+      end
       act[:manifest]=if cmd =~/y/ \
       or mod.inspect =~/"--manifest"/
         true
