@@ -225,7 +225,12 @@ WOK
         wrapped=if dob.is =='para' \
         or dob.is=='heading'
           if dob.is=='para'
-            if dob.indent =~/[1-9]/
+            if dob.hang \
+            and dob.hang =~/[0-9]/ \
+            and dob.indent != dob.hang
+              util=SiSU_text_utils::Wrap.new(dob.obj,@wrap_width,dob.indent.to_i*2,dob.hang.to_i*2)
+              #util=SiSU_text_utils::Wrap.new(dob.obj,@wrap_width,dob.hang.to_i*2,0)
+            elsif dob.indent =~/[1-9]/
               util=if dob.bullet_
                 SiSU_text_utils::Wrap.new("* #{dob.obj}",@wrap_width,dob.indent.to_i*2)
               else SiSU_text_utils::Wrap.new(dob.obj,@wrap_width,dob.indent.to_i*2)
