@@ -376,7 +376,8 @@ WOK
       txt.gsub!(/#{Mx[:gl_o]}#042#{Mx[:gl_c]}/,'*')
       txt.gsub!(/#{Mx[:gl_o]}#047#{Mx[:gl_c]}/,'/')
       txt.gsub!(/#{Mx[:gl_o]}#095#{Mx[:gl_c]}/,'_')
-      txt.gsub!(/#{Mx[:br_nl]}+/,"\n")
+      txt.gsub!(/#{Mx[:gl_o]}#092#{Mx[:gl_c]}/,'\\')
+      txt.gsub!(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})\s*/,"\n\n")                                   # watch
       txt.gsub!(/<sup><font face=symbol>&atild;<\/font><\/sup>/,' ')
       #txt.gsub!(/\\/,'\\backslash ')
       txt.gsub!(/<:pb>/,'\\newpage')
