@@ -183,7 +183,7 @@ module SiSU_TeX
         when /legal/;  pdf_p=@f.pdf_p_legal;  pdf_l=@f.pdf_l_legal
         else           pdf_p=@f.pdf_p_a4;     pdf_l=@f.pdf_l_a4
         end
-        Dir.mkdir(@md.file.output_path.pdf.dir) unless FileTest.directory?(@md.file.output_path.pdf.dir)
+        mkdir_p(@md.file.output_path.pdf.dir) unless FileTest.directory?(@md.file.output_path.pdf.dir)
         if FileTest.file?(portrait_pdf)
           cp(portrait_pdf,"#{@md.file.output_path.pdf.dir}/#{pdf_p}")
           rm(portrait_pdf)
@@ -515,8 +515,14 @@ module SiSU_TeX
             if dob.bullet_
               dob.tmp=tst.bullet
             elsif dob.indent \
-            and dob.indent =~/[1-9]/
+            and dob.hang \
+            and dob.indent =~/[1-9]/ \
+            and dob.indent == dob.hang
               dob.tmp=tst.indent
+            elsif dob.hang \
+            and dob.hang =~/[0-9]/ \
+            and (dob.indent != dob.hang or dob.indent =~/[1-9]/)
+              dob.tmp=tst.hang
             else
               dob.tmp.strip!
               dob=enclose(dob) unless dob.tmp =~/^$/
