@@ -107,7 +107,7 @@ module SiSU_XML_SAX
       def song
         begin
           SiSU_XML_SAX::Source::Scroll.new(@particulars).songsheet
-          SiSU_XML_SAX::Source::Tidy.new(@md,@env).xml if @md.opt.cmd =~/[vVM]/ # test wellformedness, comment out when not in use
+          SiSU_XML_SAX::Source::Tidy.new(@md,@file.place_file.xml_sax.dir).xml if @md.opt.cmd =~/[vVM]/ # test wellformedness, comment out when not in use
           SiSU_Rexml::Rexml.new(@md,@file.place_file.xml_sax.dir).xml if @md.opt.cmd =~/M/ # test rexml parsing, comment out when not in use #debug
         rescue; SiSU_Errors::Info_error.new($!,$@,@md.opt.cmd,@md.fns).error
         ensure
@@ -346,8 +346,13 @@ WOK
                   and dob.bullet_==true
                     xml_structure(dob,"indent_bullet#{dob.indent}")
                   elsif dob.is =~ /^para/ \
-                  and dob.indent.to_s =~/[1-9]/
+                  and dob.indent.to_s =~/[1-9]/ \
+                  and dob.indent == dob.hang
                     xml_structure(dob,"indent#{dob.indent}")
+                  elsif dob.is =~ /^para/ \
+                  and dob.hang.to_s =~/[0-9]/ \
+                  and dob.indent != dob.hang
+                    xml_structure(dob,"hang#{dob.hang.to_s}_indent#{dob.indent.to_s}")
                   else xml_structure(dob)
                   end
                 end
@@ -437,8 +442,8 @@ WOK
       end
     end
     class Tidy
-      def initialize(md,dir)
-        @md,@env=md,dir
+      def initialize(md,file)
+        @md,@file=md,file
         @prog=SiSU_Env::Info_program.new
       end
       def xml
@@ -450,7 +455,7 @@ WOK
               tell.grey_open
             end
             tidyfile='/dev/null' #don't want one or screen output, check for alternative flags
-            tidy=SiSU_Env::System_call.new("#{@env.path.output}/#{@md.fnb}/#{@md.fn[:sax]}",tidyfile)
+            tidy=SiSU_Env::System_call.new(@file,tidyfile)
             tidy.well_formed?
             tell.p_off unless @md.opt.cmd =~/q/
           end
